import csv, sys

rows = ["CA", "WA", "EA", "Precision", "CVC", "Once", "Major", "Every"]
projects = ["HCommon", "HBase", "Alluxio", "avg"]
models = ["Cd", "Cc", "Td"]


def parse_csv(csv_file):
    csv_dict = {}
    with open(csv_file, "r") as f:
        reader = csv.DictReader(f)
        for row in reader:
            #print(row)
            # add row to csv_dict
            csv_dict[row['Metrics']] = {}
            for k, v  in row.items():
                if k == "Metrics":
                    continue
                csv_dict[row['Metrics']][k] = v
    #print(csv_dict)
    return csv_dict


def draw_table(shot_name, csv_file_path):
    csv_dict = parse_csv(csv_file_path)
    table_str = ""
    macro_str = ""
    for row in rows:
        row_str = "\# {}".format(row) if row == "CA" or row == "WA" or row == "EA" else "\% {}".format(row)
        for model in models:
            for project in projects:
                macro_name = f"\{shot_name}{project}{model}{row}"
                #print(csv_dict[row])
                #print(csv_dict[row][f"{project}{model}"])
                value = csv_dict[row][f"{project}{model}"]
                if "%" in value:
                    value = value.replace("%", "\%")
                macro = "\\newcommand{%s}{%s\\xspace}" % (macro_name, value)
                print(macro)
                row_str += f" & {macro_name}"
                macro_str += macro + "\n"
            # row_str only add & except the last one
            row_str += "" if model == "Td" else " &"
        table_str += row_str + " \\\\ \n"
    print(table_str)
    

if __name__ == "__main__":
    if (len(sys.argv) != 3):
        print("Usage: python3 draw_hint_tables.py <shot_name> <csv_file_path>")
        exit(1)
    shot_name, csv_file_path = sys.argv[1:]
    draw_table(shot_name, csv_file_path)

